@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'git/command_line'
 require 'git/errors'
 require 'logger'
@@ -331,7 +333,7 @@ module Git
     def rev_parse(revision)
       assert_args_are_not_options('rev', revision)
 
-      command('rev-parse', revision)
+      command('rev-parse', '--revs-only', '--end-of-options', revision, '--')
     end
 
     # For backwards compatibility with the old method name
@@ -570,7 +572,7 @@ module Git
         case key
           when 'commit'
             hsh_array << hsh if hsh
-            hsh = {'sha' => value, 'message' => '', 'parent' => []}
+            hsh = {'sha' => value, 'message' => +'', 'parent' => []}
           when 'parent'
             hsh['parent'] << value
           else
@@ -1545,7 +1547,8 @@ module Git
         'GIT_DIR' => @git_dir,
         'GIT_WORK_TREE' => @git_work_dir,
         'GIT_INDEX_FILE' => @git_index_file,
-        'GIT_SSH' => Git::Base.config.git_ssh
+        'GIT_SSH' => Git::Base.config.git_ssh,
+        'LC_ALL' => 'en_US.UTF-8'
       }
     end
 
